clear all
version 12
set more off

* calculate log difference in personal income over re-timed year to correspond
* with sampling period in the BDS

* national
import excel using "raw/cyclical_indicators.xlsx", clear first sh("national")

* obtain numeric year-quarter date
gen year=year(excel)
gen quarter = quarter(excel)
gen date=yq(year,quarter)
format date %tq

* generate retimed year/month variables
gen newyear = .
gen newq = .
replace newq = quarter-1 if quarter>=2
replace newq = quarter+3 if quarter==1
replace newyear = year+1 if newq<=3
replace newyear = year if newq==4

rename year oldyear
rename quarter oldquarter
rename newq quarter
rename newyear year

ren YPDHUSNA rpi
drop if mi(excel)
destring rpi, replace

* generate log vals of pi
gen ln_pi = ln(rpi)

tsset date
* HP filter ln_pi -- use lambda=1600 (standard for STATA quarterly data -- included manually for reference)
hprescott ln_pi, stub(HP) s(1600)

* collapse by year, keeping the two pi measures (one final, one intermediate)
collapse (mean) ln_pi HP_ln_pi_1, by(year)
tsset year

* calculate final pi measure
gen pi_method1 = ln_pi - L1.ln_pi
gen pi_method2 = HP_ln_pi_1

label var pi_method1 "logQ1pi - L1.logQ1pi"
label var pi_method2 "HP filter, average deviations"

keep year ln_pi pi_method1 pi_method2
ren year year2
saveold cyclical_indicators, replace



* state
import excel using "raw/cyclical_indicators.xlsx", clear first sh("state")

* obtain numeric year-quarter date
gen year=year(excel)
gen quarter = quarter(excel)
gen date=yq(year,quarter)
format date %tq

* generate retimed year/month variables
gen newyear = .
gen newq = .
replace newq = quarter-1 if quarter>=2
replace newq = quarter+3 if quarter==1
replace newyear = year+1 if newq<=3
replace newyear = year if newq==4

rename year oldyear
rename quarter oldquarter
rename newq quarter
rename newyear year

foreach v of var *PHQPIQR {
  loc ren = `v'[4]
  ren `v' rpi`ren'
  gen mil`ren' = (strpos(rpi`ren',"Mil")!=0)
  replace mil`ren' = mil`ren'[1]
  }
drop if mi(excel)

keep year quarter date rpi* mil* 
reshape long rpi mil, i(year quarter date) j(state) s
destring rpi mil, replace

* not all personal income is in millions -- scale appropriately
replace rpi = rpi/1000 if mil==0

* generate log vals of pi
gen ln_pi = ln(rpi)

collapse (mean) ln_pi, by(state year)

* difference after collapsing
destring state, replace
tsset state year

* calculate final pi measure
gen pi_method1 = D.ln_pi

keep year state pi_method1
ren year year2

saveold cyclical_indicators_state, replace

