* output 1987:2012 age group data for simulation
version 12
clear all

/************ generate cyclical variables from state-level data *********/
tempfile cyclical_vars

/** step 1: compute betas using cross state variation**/
use bds_2groups_state, clear
merge m:1 year2 state using cyclical_indicators_state
egen empyr = sum(emp), by(year2 ageg) /* weight equally across years within age groups*/
gen wgt = emp/empyr
keep if year2 >= 1980
/** filter state-level startup growth **/
preserve
keep if ageg == 1
/* linear trend */
reg njcr i.state i.state#c.year2
predict gs_t_res if ageg == 1, resid
predict gs_t_res_s  if ageg == 1
tempfile filtered_data
keep year2 state ageg gs_t_*
save `filtered_data'
restore
merge m:1 year2 state ageg using `filtered_data', nogen

/** estimate betas by age group */
* young
reg njcr c.pi_method1 i.state i.year2 [aw=wgt] if ageg == 2, cluster(state)
gen beta = _b[pi_method1] if ageg == 2
* mature 
reg njcr c.pi_method1 i.state i.year2 [aw=wgt] if ageg == 3, cluster(state)
replace beta = _b[pi_method1] if ageg == 3
* startups
reg gs_t_res /*gs_t_hp_6*/ /*gs_t_hp_100*/ pi_method1 i.state i.year2 [aw=wgt] if ageg == 1, cluster(state)
replace beta = _b[pi_method1] if ageg==1 
* collapse and remergesig
collapse (mean) beta, by(year2 ageg)

/** step 2: define national cyclical variables using state-level betas **/
merge 1:1 year2 ageg using bds_2groups, nogen
merge m:1 year2 using cyclical_indicators, nogen 
replace njcr = njcr - 1 if ageg == 1 /* njcr defined as 1 + gs_t */

* trend component: startups
/*
reg njcr year2 if ageg == 1 & beta < . & year2 <= 2007
predict trend if ageg == 1 & beta < .
*/

preserve
tempfile startup_trend
keep if ageg == 1
tsset year2
tsfilter hp gs_t_hp_100 = njcr if year2 >= 1980, s(6) trend(trend)
save `startup_trend'
restore
merge 1:1 year2 ageg using `startup_trend', keepusing(trend) nogenerate

* trend component: incumbents
tempvar xtrend
egen `xtrend' = mean(njcr), by(ageg)
replace trend = `xtrend' if ageg != 1
* cyclical component for y/m by multiplying by de-meaned shock
reg pi_method1 if year2 >= 1987
predict shock, resid
gen double cyc = shock*beta 
* generate residual for matlab
gen double resid = njcr - trend - cyc 

save `cyclical_vars'
/************************************************************************/

use bds_2groups
merge 1:1 year2 ageg using `cyclical_vars'
keep if ageg < .

keep year2 ageg emp emptot emplag1tot empshr emplag1shr njcr njcrtot firmsurv avgsize avgsizegrowth trend beta shock cyc resid
reshape wide emp empshr emplag1shr njcr njcrtot firmsurv avgsize avgsizegrowth trend beta shock cyc resid, i(year2) j(ageg)

gen long emp_s = emp1
gen long emp_y = emp2
gen long emp_m = emp3

gen long emp_t = emptot
gen long emp_tm1 = emplag1tot

gen double empshr_s = empshr1
gen double empshr_y = empshr2
gen double empshr_m = empshr3

gen double njcr_s = njcr1
gen double njcr_y = njcr2
gen double njcr_m = njcr3

gen double njcrtot = njcrtot1

gen double firmsurv_y = firmsurv2
gen double firmsurv_m = firmsurv3

gen double avgsize_s = avgsize1
gen double avgsize_y = avgsize2
gen double avgsize_m = avgsize3

gen double avgsizegrowth_y = avgsizegrowth2
gen double avgsizegrowth_m = avgsizegrowth3

gen double emplag1shr_s = emplag1shr1
gen double emplag1shr_y = emplag1shr2
gen double emplag1shr_m = emplag1shr3

gen double mu = trend1
gen double gbar_y = trend2
gen double gbar_m = trend3

gen gc_s = cyc1
gen gc_y = cyc2
gen gc_m = cyc3

gen double resid_s = resid1
gen double resid_y = resid2 
gen double resid_m = resid3

gen beta_s = beta1
gen beta_y = beta2
gen beta_m = beta3

gen shock = shock1

preserve
keep if year >= 1987
keep year2 emp_* empshr_* njcr_* njcrtot firmsurv_* avgsize_* ///
  avgsizegrowth_* emplag1shr_* gc_* mu gbar_* resid_* beta_* shock
descr
outsheet using bds_2group_wide.txt, replace
restore

preserve
keep if year >= 1980
keep year2 emp_s empshr_s emp_t emp_tm1 njcr_s njcrtot avgsize_s emplag1shr_s gc_s mu resid_s beta_s shock
descr
outsheet using bds_startupshare_wide.txt, replace
restore




